@@ -1,4 +1,6 @@
 /*
+ Copyright (c) 2020 Red Hat, Inc.
+
 Licensed Materials - Property of IBM
 cfc
 @ Copyright IBM Corp. 2018 All Rights Reserved
@@ -42,16 +44,16 @@ import (
 	ngx_template "github.com/open-cluster-management/management-ingress/pkg/ingress/controller/template"
 	"github.com/open-cluster-management/management-ingress/pkg/ingress/status"
 	"github.com/open-cluster-management/management-ingress/pkg/ingress/store"
+	ing_net "github.com/open-cluster-management/management-ingress/pkg/net"
 	"github.com/open-cluster-management/management-ingress/pkg/net/dns"
 	"github.com/open-cluster-management/management-ingress/pkg/task"
 	"github.com/open-cluster-management/management-ingress/pkg/watch"
-	ing_net "github.com/open-cluster-management/management-ingress/pkg/net"
 )
 
 var (
-	tmplPath    = "/opt/ibm/router/nginx/template/nginx.tmpl"
-	cfgPath     = "/opt/ibm/router/nginx/conf/nginx.conf"
-	nginxBinary = "/opt/ibm/router/nginx/sbin/nginx"
+	tmplPath        = "/opt/ibm/router/nginx/template/nginx.tmpl"
+	cfgPath         = "/opt/ibm/router/nginx/conf/nginx.conf"
+	nginxBinary     = "/opt/ibm/router/nginx/sbin/nginx"
 	nginxBinaryFIPS = "/opt/ibm/router/nginx/sbin/nginx-fips"
 )
 
@@ -60,7 +62,7 @@ var (
 // as source for nginx commands
 func NewNGINXController(config *Configuration, fs file.Filesystem) *NGINXController {
 	ngx := os.Getenv("NGINX_BINARY")
-        fips := os.Getenv("FIPS_ENABLED")
+	fips := os.Getenv("FIPS_ENABLED")
 
 	if ngx == "" {
 		if fips == "true" {
@@ -86,7 +88,7 @@ func NewNGINXController(config *Configuration, fs file.Filesystem) *NGINXControl
 
 		configmap: &apiv1.ConfigMap{},
 
-                isIPV6Enabled: ing_net.IsIPv6Enabled(),
+		isIPV6Enabled: ing_net.IsIPv6Enabled(),
 
 		resolver:        h,
 		cfg:             config,
@@ -240,6 +242,7 @@ func (n *NGINXController) Start() {
 	go wait.Until(n.checkMissingSecrets, 30*time.Second, n.stopCh)
 
 	done := make(chan error, 1)
+	// #nosec
 	cmd := exec.Command(n.binary, "-c", cfgPath)
 
 	// put nginx in another process group to prevent it
@@ -271,7 +274,10 @@ func (n *NGINXController) Start() {
 			if process.IsRespawnIfRequired(err) {
 				process.WaitUntilPortIsAvailable(n.cfg.ListenPorts.HTTP)
 				// release command resources
-				cmd.Process.Release()
+				if err := cmd.Process.Release(); err != nil {
+					glog.Warningf("unexpected error release command resources: %v", err)
+				}
+				// #nosec
 				cmd = exec.Command(n.binary, "-c", cfgPath)
 				// start a new nginx master process if the controller is not being stopped
 				n.start(cmd)
@@ -303,6 +309,7 @@ func (n *NGINXController) Stop() error {
 
 	// Send stop signal to Nginx
 	glog.Info("stopping NGINX process...")
+	// #nosec
 	cmd := exec.Command(n.binary, "-c", cfgPath, "-s", "quit")
 	cmd.Stdout = os.Stdout
 	cmd.Stderr = os.Stderr
@@ -354,9 +361,11 @@ func (n *NGINXController) SetConfig(cmap *apiv1.ConfigMap) {
 			glog.Warningf("unexpected error decoding key ssl-session-ticket-key: %v", err)
 			c.SSLSessionTicketKey = ""
 		}
-		ioutil.WriteFile("/etc/nginx/tickets.key", d, 0644)
-	}
 
+		if err := ioutil.WriteFile("/etc/nginx/tickets.key", d, 0600); err != nil {
+			glog.Warningf("unexpected error writing /etc/nginx/tickets.key: %v", err)
+		}
+	}
 }
 
 // OnUpdate is called periodically by syncQueue to keep the configuration in sync.
@@ -378,21 +387,21 @@ func (n *NGINXController) OnUpdate(ingressCfg ingress.Configuration) error {
 	if err != nil {
 		wp = 1
 	}
-	maxOpenFiles := (sysctlFSFileMax() / wp) - 1024
-	glog.V(3).Infof("maximum number of open file descriptors : %v", sysctlFSFileMax())
+	maxOpenFiles := (rlimitMaxNumFiles() / wp) - 1024
+	glog.V(3).Infof("maximum number of open file descriptors : %v", rlimitMaxNumFiles())
 	if maxOpenFiles < 1024 {
 		// this means the value of RLIMIT_NOFILE is too low.
 		maxOpenFiles = 1024
 	}
 
 	tc := ngx_config.TemplateConfig{
-		MaxOpenFiles: maxOpenFiles,
-		BacklogSize:  sysctlSomaxconn(),
-		Backends:     ingressCfg.Backends,
-		Servers:      ingressCfg.Servers,
-		Cfg:          cfg,
-                IsIPV6Enabled:  n.isIPV6Enabled && !cfg.DisableIpv6,
-		ListenPorts:  n.cfg.ListenPorts,
+		MaxOpenFiles:  maxOpenFiles,
+		BacklogSize:   sysctlSomaxconn(),
+		Backends:      ingressCfg.Backends,
+		Servers:       ingressCfg.Servers,
+		Cfg:           cfg,
+		IsIPV6Enabled: n.isIPV6Enabled && !cfg.DisableIpv6,
+		ListenPorts:   n.cfg.ListenPorts,
 	}
 
 	content, err := n.t.Write(tc)
@@ -413,13 +422,15 @@ func (n *NGINXController) OnUpdate(ingressCfg ingress.Configuration) error {
 			if err != nil {
 				return err
 			}
+			// #nosec
 			defer tmpfile.Close()
-			err = ioutil.WriteFile(tmpfile.Name(), content, 0644)
+			err = ioutil.WriteFile(tmpfile.Name(), content, 0600)
 			if err != nil {
 				return err
 			}
 
 			// executing diff can return exit code != 0
+			// #nosec
 			diffOutput, _ := exec.Command("diff", "-u", cfgPath, tmpfile.Name()).CombinedOutput()
 
 			glog.Infof("NGINX configuration diff\n")
@@ -429,15 +440,17 @@ func (n *NGINXController) OnUpdate(ingressCfg ingress.Configuration) error {
 			// This is helpful when there is an error in the
 			// temporal configuration (we can manually inspect the file).
 			// Only remove the file when no error occurred.
-			os.Remove(tmpfile.Name())
+			if err := os.Remove(tmpfile.Name()); err != nil {
+				return err
+			}
 		}
 	}
 
-	err = ioutil.WriteFile(cfgPath, content, 0644)
+	err = ioutil.WriteFile(cfgPath, content, 0600)
 	if err != nil {
 		return err
 	}
-
+	// #nosec
 	o, err := exec.Command(n.binary, "-s", "reload", "-c", cfgPath).CombinedOutput()
 	if err != nil {
 		return fmt.Errorf("%v\n%v", err, string(o))
@@ -456,11 +469,13 @@ func (n NGINXController) testTemplate(cfg []byte) error {
 	if err != nil {
 		return err
 	}
+	// #nosec
 	defer tmpfile.Close()
-	err = ioutil.WriteFile(tmpfile.Name(), cfg, 0644)
+	err = ioutil.WriteFile(tmpfile.Name(), cfg, 0600)
 	if err != nil {
 		return err
 	}
+	// #nosec
 	out, err := exec.Command(n.binary, "-t", "-c", tmpfile.Name()).CombinedOutput()
 	if err != nil {
 		// this error is different from the rest because it must be clear why nginx is not working
@@ -473,6 +488,9 @@ Error: %v
 		return errors.New(oe)
 	}
 
-	os.Remove(tmpfile.Name())
+	if err := os.Remove(tmpfile.Name()); err != nil {
+		return err
+	}
+
 	return nil
 }
